@@ -1,5 +1,5 @@
 #	pyradium - HTML presentation/slide show generator
-#	Copyright (C) 2015-2021 Johannes Bauer
+#	Copyright (C) 2015-2022 Johannes Bauer
 #
 #	This file is part of pyradium.
 #
@@ -23,6 +23,7 @@ class PyRadiumException(Exception): pass
 
 class CallingProcessException(PyRadiumException): pass
 
+class XMLFileNotFoundException(PyRadiumException): pass
 class MalformedXMLInputException(PyRadiumException): pass
 class MalformedStyleConfigurationException(PyRadiumException): pass
 
@@ -34,9 +35,17 @@ class UsageException(SlideException): pass
 
 class XMLHookRegistryException(PyRadiumException): pass
 
+class InvalidTransformationException(PyRadiumException): pass
+
 class DuplicateOrderException(PyRadiumException): pass
 class InvalidBooleanValueException(PyRadiumException): pass
 class FailedToLookupFileException(PyRadiumException): pass
+class InvalidTeXException(PyRadiumException): pass
+class UnknownSlideTypeException(PyRadiumException): pass
+
+class AcronymException(PyRadiumException): pass
+class InvalidAcronymFileException(AcronymException): pass
+class DuplicateAcronymException(AcronymException): pass
 
 class FailedToExecuteSubprocessException(PyRadiumException): pass
 
